@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "org-vcard" "0.3.1"
+(define-package "org-vcard" "20250828.809"
   "Org-mode support for vCard export and import."
   '((emacs "24.4"))
   :url "https://github.com/pinoaffe/org-vcard"
